==> molview_messages-0.2.3.tar.gz: lib/src/dataserver/snippet.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Snippet selector
///
/// A snippet is a piece of data with a specific data class. This data snippet
/// can be retrieved from any table that contains a field that matches this
/// snippet. You can also force an origin database and table.
class SnippetSelector {
  /// Origin database
  final String database;

  /// Origin table
  final String table;

  /// Desired data class
  final String dataClass;

  /// Desired properties
  final Map<String, dynamic> properties;

  /// Input parameters
  final Map<String, dynamic> parameters;

  /// Constructor
  SnippetSelector(this.dataClass,
      {this.database: '',
      this.table: '',
      this.properties: const {},
      this.parameters: const {}});

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'database': database,
      'table': table,
      'dataClass': dataClass,
      'properties': properties,
      'parameters': parameters
    };
  }
}

/// Snippet data
class SnippetData {
  /// Origin database
  final String database;

  /// Origin table
  final String table;

  /// Data class
  final String dataClass;

  /// Snippet content
  final dynamic content;

  /// Constructor
  SnippetData(this.database, this.table, this.dataClass, this.content);

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'database': database,
      'table': table,
      'dataClass': dataClass,
      'content': content
    };
  }
}

==> molview_messages-0.4.0.tar.gz: lib/src/dataserver/snippet.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Snippet selector
///
/// A snippet is a piece of data with a specific data class. This data snippet
/// can be retrieved from any table that contains a field that matches this
/// snippet. You can also force an origin database and table.
class SnippetSelector {
  /// Origin database
  final String database;

  /// Origin table
  final String table;

  /// Desired data class
  final String dataClass;

  /// Desired properties
  final Map<String, String> properties;

  /// Input parameters
  final Map<String, String> parameters;

  /// Constructor
  SnippetSelector(this.dataClass,
      {this.database: '',
      this.table: '',
      this.properties: const {},
      this.parameters: const {}});

  /// Construct from JSON data.
  factory SnippetSelector.fromJson(Map<String, dynamic> data) {
    return new SnippetSelector(data['class'],
        database: data['database'],
        table: data['table'],
        properties: data['properties'] as Map<String, String>,
        parameters: data['properties'] as Map<String, String>);
  }

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'database': database,
      'table': table,
      'class': dataClass,
      'properties': properties,
      'parameters': parameters
    };
  }
}

/// Snippet data
class SnippetData {
  /// Origin database
  final String database;

  /// Origin table
  final String table;

  /// Data class
  final String dataClass;

  /// Snippet content
  final dynamic content;

  /// Constructor
  SnippetData(this.database, this.table, this.dataClass, this.content);

  /// Construct from JSON data.
  factory SnippetData.fromJson(Map<String, dynamic> data) {
    return new SnippetData(
        data['database'], data['table'], data['class'], data['content']);
  }

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'database': database,
      'table': table,
      'class': dataClass,
      'content': content
    };
  }
}
